pub struct Shipment {
Show 15 fields pub shipment_id: String, pub amazon_order_id: String, pub seller_order_id: Option<String>, pub item_list: Vec<Item>, pub ship_from_address: Box<Address>, pub ship_to_address: Box<Address>, pub package_dimensions: Box<PackageDimensions>, pub weight: Box<Weight>, pub insurance: Box<CurrencyAmount>, pub shipping_service: Box<ShippingService>, pub label: Box<Label>, pub status: ShipmentStatus, pub tracking_id: Option<String>, pub created_date: String, pub last_updated_date: Option<String>,
}
Shipment : The details of a shipment, including the shipment status.

Fields

shipment_id: String

An Amazon-defined shipment identifier.

amazon_order_id: String

An Amazon-defined order identifier, in 3-7-7 format.

seller_order_id: Option<String>

A seller-defined order identifier.

item_list: Vec<Item>

The list of items to be included in a shipment.

ship_from_address: Box<Address>ship_to_address: Box<Address>package_dimensions: Box<PackageDimensions>weight: Box<Weight>insurance: Box<CurrencyAmount>shipping_service: Box<ShippingService>label: Box<Label>status: ShipmentStatustracking_id: Option<String>

The shipment tracking identifier provided by the carrier.

created_date: Stringlast_updated_date: Option<String>

Implementations

The details of a shipment, including the shipment status.